/*******************************************************************************
 * This class defines contact list
 * @author Karolina Krolik <a href='mailto:k.krolik@samsung.com'>k.krolik@samsung.com</a>
 * @author Tomasz Scislo <a href='mailto:t.scislo@samsung.com'>t.scislo@samsung.com</a>
 * @author Lukasz Jagodzinski <a href='mailto:l.jagodzinsk@samsung.com'>l.jagodzinsk@samsung.com</a>
 * Copyright (c) 2012 Samsung Electronics All Rights Reserved.
 ******************************************************************************/

var contact = function (options) {
    this.number      = options.number;
    this.firstName   = options.firstName;
    this.secondName  = options.secondName;
    this.connections = options.connections;
    this.sms         = options.sms;
    this.duration    = options.duration;

    var _callTo;

    // return phone number without "+" at the beginning
    this.numberNoPlus = function () {
        return this.number.replace('+', '');
    };

    /**
     * Add a new connection (call/sms) to contact. Increase call/sms count and
     * call duration for each period (week, month, total).
     *
     * @param con Connection object
     */
    this.addConnection = function (con) {
        var oneDay = 1000 * 60 * 60 * 24;
        var today = new Date();
        var delta = (today.getTime() - con.date.getTime()) / oneDay;

        if (delta < 7) {
            this.connections.week += con.connection;
            this.duration.week += con.duration;
            this.sms.week += con.sms;
        }
        if (delta < 30) {
            this.connections.month += con.connection;
            this.duration.month += con.duration;
            this.sms.month += con.sms;
        }
        this.connections.total += con.connection;
        this.duration.total += con.duration;
        this.sms.total += con.sms;
    };

    /**
     * Return contact information as a list item. Connection information is
     * given for the time period specified as a parameter.
     *
     * @param curPeriod Display period
     * @returns List element with contact information (jQuery object)
     */
    this.toHTML = function (curPeriod) {
        var name;
        if (this.firstName !== '') {
            name = this.firstName;
        } else {
            name = this.number;
        }
        var smsDisplay, connectionsDisplay, durationDisplay;

        switch (curPeriod) {
        case LoveMeter.getDisplayMode().WEEK:
            smsDisplay = this.sms.week;
            connectionsDisplay = this.connections.week;
            durationDisplay = this.duration.week;
            break;
        case LoveMeter.getDisplayMode().MONTH:
            smsDisplay = this.sms.month;
            connectionsDisplay = this.connections.month;
            durationDisplay = this.duration.month;
            break;
        default:
            smsDisplay = this.sms.total;
            connectionsDisplay = this.connections.total;
            durationDisplay = this.duration.total;
            break;
        }

        var element = $('<li data-id="' + this.number + '" id="contact_' + this.numberNoPlus() + '"><a href="#main">' + this.secondName + ' ' + name + '</a><span class="button connections"><span class="lm">' + connectionsDisplay + '</span></span><span class="button sms"><span class="lm">' + smsDisplay + '</span></span><span class="button duration"><span class="lm">' + durationDisplay + '</span></span></li>');

        return element;
    };

    /**
     * Launch application "phone" with selected phone number
     *
     * @param num Phone number
     */
    _callTo = function (number) {
        var onSuccess,
            onError;

        onSuccess = function () {
            tizen.logger.log('Appcontrol launch succeded');
        };

        onError = function (err) {
            tizen.logger.err('Appcontrol launch failed: ' + err.message);
        };

        if (number) {
            number = 'tel:' + number;
            var appControl = new tizen.ApplicationControl('http://tizen.org/appcontrol/operation/dial', number, null);

            try {
                tizen.application.launchAppControl(appControl, null, onSuccess, onError, null);
            } catch (exc) {
                tizen.logger.err('Appcontrol launch exception: ' + exc.message);
            }
        } else {
            // If the contact doesn't have proper phone number contact.phoneNumbers[0] is undefined
            tizen.view.showPopup('Phone number is undefined!');
        }
    };

    /**
     * Call this contact's number
     */
    this.call = function () {
        tizen.logger.info('Calling... ' + this.number);
        _callTo(this.number);
    };

    /**
     * Listener for clicking on contact list item. Call call() method of the clicked contact.
     */
    this.addClickEventListener = function () {
        var number = this.numberNoPlus();
        var that = this;
        $('#contact_' + number).bind({
            click: function () {
                that.call();
            }
        });
    };
};