/*******************************************************************************
 * This class defines contact list
 * @author Karolina Krolik <a href='mailto:k.krolik@samsung.com'>k.krolik@samsung.com</a>
 * @author Tomasz Scislo <a href='mailto:t.scislo@samsung.com'>t.scislo@samsung.com</a>
 * @author Lukasz Jagodzinski <a href='mailto:l.jagodzinsk@samsung.com'>l.jagodzinsk@samsung.com</a>
 * Copyright (c) 2012 Samsung Electronics All Rights Reserved.
 ******************************************************************************/

var contactList = function () {
    var contacts = [];
    var filters = [];
    var addressbook = tizen.contact.getDefaultAddressBook();

    /**
     * Callback for contact search success. Function updates first name and second name in contacts[] array for the item found in address book.
     *
     * @param ContactsFound Contacts returned from address book query
     */
    var onContactSearchSuccess = function (contactsFound, callback) {
        var i;
        for (i = 0; i < contactsFound.length; i++) {
            for (var j = 0; j < contacts.length; j++) {
                if (contactsFound[i].phoneNumbers[0].number === contacts[j].number) {
                    contacts[j].firstName = contactsFound[i].name.firstName;
                    contacts[j].secondName = contactsFound[i].name.lastName;
                    break;
                }
            }
        }
        if (typeof callback === "function") {
            callback();
        }
    };

    /**
     * Callback for error in address book search
     */
    var onFindError = function () {
        tizen.logger.err('Contact search error!');
    };

    /**
     * Method to match numbers with contacts from address book.
     *
     * @param {function} callback - will be called when maching is finished
     */
    this.matchNames = function (callback) {
        var filter = new tizen.CompositeFilter("UNION", filters);
        addressbook.find(function (contactsFound) {
            onContactSearchSuccess(contactsFound, callback);
        }, onFindError, filter);
    };

    /**
     * Add connection to already existing contact or create a new contact if it isn't in contacts[] array.
     *
     * @param con New connection to add to array
     */
    this.add = function (con) {
        if (!con.number) {
            return;
        }
        if (contacts.length > 0) {
            for (var i = 0; i < contacts.length; i++) {
                if (con.number === contacts[i].number) {
                    contacts[i].addConnection(con);

                    return;
                }
            }
        }

        var contactTemp = new contact({
            number: con.number,
            firstName: '',
            secondName: '',
            sms: new count({
                week: 0,
                month: 0,
                total: 0
            }),
            connections: new count({
                week: 0,
                month: 0,
                total: 0
            }),
            duration: new count({
                week: 0,
                month: 0,
                total: 0
            })
        });
        contactTemp.addConnection(con);
        contacts.push(contactTemp);
        filters.push(new tizen.AttributeFilter('phoneNumbers.number', 'EXACTLY', con.number));
    };

    /**
     * Get contact object with specified index
     *
     * @param i Object index
     */
    this.get = function (i) {
        return contacts[i];
    };

    /**
     * Get length of contacts[] array
     */
    this.getLength = function () {
        return contacts.length;
    };

    /**
     * Sort contact[] array by SMS count in given period
     *
     * @param period SMS count period
     * @param order Sort order (descending/ascending)
     */
    this.sortBySMS = function (period, order) {
        switch (period) {
        case LoveMeter.getDisplayMode().WEEK:
            if (order === LoveMeter.getSortOrder().ASCENDING) {
                contacts.sort(function (a, b) {

                    return parseInt(a.sms.week) - parseInt(b.sms.week, 10);
                });
            } else {
                contacts.sort(function (a, b) {
                    return parseInt(b.sms.week) - parseInt(a.sms.week, 10);
                });
            }

            break;
        case LoveMeter.getDisplayMode().MONTH:
            if (order === LoveMeter.getSortOrder().ASCENDING) {
                contacts.sort(function (a, b) {
                    return parseInt(a.sms.month) - parseInt(b.sms.month, 10);
                });
            } else {
                contacts.sort(function (a, b) {
                    return parseInt(b.sms.month) - parseInt(a.sms.month, 10);
                });
            }
            break;
        default:
            if (order === LoveMeter.getSortOrder().ASCENDING) {
                contacts.sort(function (a, b) {
                    return parseInt(a.sms.total) - parseInt(b.sms.total, 10);
                });
            } else {
                contacts.sort(function (a, b) {
                    return parseInt(b.sms.total) - parseInt(a.sms.total, 10);
                });
            }
            break;
        }

    };

    /**
     * Sort contact[] array by call duration count in given period
     *
     * @param period Call duration count period
     * @param order Sort order (descending/ascending)
     */
    this.sortByDuration = function (period, order) {
        switch (period) {
        case LoveMeter.getDisplayMode().WEEK:
            if (order === LoveMeter.getSortOrder().ASCENDING) {
                contacts.sort(function (a, b) {
                    return parseInt(a.duration.week) - parseInt(b.duration.week, 10);
                });
            } else {
                contacts.sort(function (a, b) {
                    return parseInt(b.duration.week) - parseInt(a.duration.week, 10);
                });
            }
            break;
        case LoveMeter.getDisplayMode().MONTH:
            if (order === LoveMeter.getSortOrder().ASCENDING) {
                contacts.sort(function (a, b) {
                    return parseInt(a.duration.month) - parseInt(b.duration.month, 10);
                });
            } else {
                contacts.sort(function (a, b) {
                    return parseInt(b.duration.month) - parseInt(a.duration.month, 10);
                });
            }
            break;
        default:
            if (order === LoveMeter.getSortOrder().ASCENDING) {
                contacts.sort(function (a, b) {
                    return parseInt(a.duration.total) - parseInt(b.duration.total, 10);
                });
            } else {
                contacts.sort(function (a, b) {
                    return parseInt(b.duration.total) - parseInt(a.duration.total, 10);
                });
            }
        }
    };

    /**
     * Sort contact[] array by connections count in given period
     *
     * @param period Connections count period
     * @param order Sort order (descending/ascending)
     */
    this.sortByConnections = function (dispMode, order) {

        switch (dispMode) {
        case LoveMeter.getDisplayMode().WEEK:
            if (order === LoveMeter.getSortOrder().ASCENDING) {
                contacts.sort(function (a, b) {
                    return parseInt(a.connections.week) - parseInt(b.connections.week, 10);
                });
            } else {
                contacts.sort(function (a, b) {
                    return parseInt(b.connections.week) - parseInt(a.connections.week, 10);
                });
            }
            break;
        case LoveMeter.getDisplayMode().MONTH:

            if (order === LoveMeter.getSortOrder().ASCENDING) {
                contacts.sort(function (a, b) {
                    return parseInt(a.connections.month) - parseInt(b.connections.month, 10);
                });
            } else {
                contacts.sort(function (a, b) {
                    return parseInt(b.connections.month) - parseInt(a.connections.month, 10);
                });
            }
            break;
        default:
            if (order === LoveMeter.getSortOrder().ASCENDING) {
                contacts.sort(function (a, b) {
                    return parseInt(a.connections.total) - parseInt(b.connections.total, 10);
                });
            } else {
                contacts.sort(function (a, b) {
                    return parseInt(b.connections.total) - parseInt(a.connections.total, 10);
                });
            }
        }
    };
};